==> redquicklib-1.17.0.tgz: package/lib/redservice.js <==
import createService from './service';
import { parameters } from './endPoints';
import * as Globals from './globals';

const endpoints = {
    GetUIDefinition: (objectType) => `api/${objectType}/ui/definition`,
    GetRedObject: (objectType, id) => `api/${objectType}/${id}`,
    UpdateRedObject: (objectType, id) => `api/${objectType}/${id}`,
    DeleteRedObject: (objectType, id) => `api/${objectType}/${id}`,
    CreateRedObject: (objectType) => `api/${objectType}`,
}

var formatjson = '?format=json';
var redservice = createService(Globals.DEFAULT_URL);

export default {
    getWebRTC: async () => {
        return redservice.get(endpoints.GetWebRTC);
    },
    getPermissions: async () => {
        return redservice.get(parameters(endpoints.GetPermissions));
    },
    requestUploadEndpoint: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice.post(endpoints.RequestUploadEndpoint, body);
    },
    completeUpload: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice.post(endpoints.CompleteUpload, body);
    },
    getResources: async req => {
        var body = JSON.stringify(req);

        return redservice.post(endpoints.GetResources, body);
    },
    getNotifications: async (signature) => {
        return redservice.get(parameters(endpoints.GetNotifications, signature));
    },
    deleteResource: async id => {
        return redservice.delete(parameters(endpoints.DeleteResources, id));
    },
    emitMessage: async (to, body) => {
        return redservice.post(parameters(endpoints.EmitMessage, to), body);
    },
    getUIDefinition: async (objectType) => {
        return redservice.get(endpoints.GetUIDefinition(objectType));
    },
    getRedObject: async (args) => {
        var { objectType, id } = args;
        return redservice.get(endpoints.GetRedObject(objectType, id));
    },
    updateRedObject: async (args) => {
        var { objectType, id, obj } = args;
        var body = JSON.stringify(obj);
        return redservice.put(endpoints.UpdateRedObject(objectType, id), body);
    },
    createRedObject: async (args) => {
        var { objectType, obj } = args;
        var body = JSON.stringify(obj);
        return redservice.put(endpoints.CreateRedObject(objectType), body);
    },
    deleteRedObject: async (args) => {
        var { objectType, id } = args;
        return redservice.delete(endpoints.DeleteRedObject(objectType, id));
    }
}

==> redquicklib-1.27.0.tgz: package/lib/redservice.js <==
import createService from './service';
import { parameters } from './endPoints';
import * as Globals from './globals';

const endpoints = {
    GetDefaultDefinition: (objectType) => `api/${objectType}/ui/default`,
    GetUIDefinition: (objectType) => `api/${objectType}/ui/definition`,
    GetAll: (objectType) => `api/${objectType}/all`,
    GetRedObject: (objectType, id) => `api/${objectType}/${id}`,
    UpdateRedObject: (objectType, id) => `api/${objectType}/${id}`,
    DeleteRedObject: (objectType, id) => `api/${objectType}/${id}`,
    CreateRedObject: (objectType) => `api/${objectType}`,
}

var formatjson = '?format=json';
var redservice = createService(Globals.DEFAULT_URL);

export default {
    getWebRTC: async () => {
        return redservice.get(endpoints.GetWebRTC);
    },
    getPermissions: async () => {
        return redservice.get(parameters(endpoints.GetPermissions));
    },
    requestUploadEndpoint: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice.post(endpoints.RequestUploadEndpoint, body);
    },
    completeUpload: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice.post(endpoints.CompleteUpload, body);
    },
    getResources: async req => {
        var body = JSON.stringify(req);

        return redservice.post(endpoints.GetResources, body);
    },
    getNotifications: async (signature) => {
        return redservice.get(parameters(endpoints.GetNotifications, signature));
    },
    deleteResource: async id => {
        return redservice.delete(parameters(endpoints.DeleteResources, id));
    },
    emitMessage: async (to, body) => {
        return redservice.post(parameters(endpoints.EmitMessage, to), body);
    },
    getUIDefinition: async (objectType) => {
        return redservice.get(endpoints.GetUIDefinition(objectType));
    },
    getUIDefault: async (objectType) => {
        return redservice.get(endpoints.GetDefaultDefinition(objectType));
    },
    getRedObject: async (args) => {
        var { objectType, id } = args;
        return redservice.get(endpoints.GetRedObject(objectType, id));
    },
    getAllRedObject: async (args) => {
        var { objectType } = args;
        return redservice.get(endpoints.getAllRedObject(objectType));
    },
    updateRedObject: async (args) => {
        var { objectType, id, obj } = args;
        var body = JSON.stringify(obj);
        return redservice.put(endpoints.UpdateRedObject(objectType, id), body);
    },
    createRedObject: async (args) => {
        var { objectType, obj } = args;
        var body = JSON.stringify(obj);
        return redservice.post(endpoints.CreateRedObject(objectType), body);
    },
    deleteRedObject: async (args) => {
        var { objectType, id } = args;
        return redservice.delete(endpoints.DeleteRedObject(objectType, id));
    }
}
